==> eiffelstudio-18.07.10.1981.tar: F_code/C1/ch29.h <==

#ifndef _C1_ch29_
#define _C1_ch29_

#ifdef __cplusplus
extern "C" {
#endif

extern void F33_363(EIF_REFERENCE);
extern EIF_CHARACTER_32 F33_376(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,388)
static EIF_REFERENCE F33_388_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_388(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,389)
static EIF_REFERENCE F33_389_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_389(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,390)
static EIF_REFERENCE F33_390_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_390(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,391)
static EIF_REFERENCE F33_391_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_391(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,392)
static EIF_REFERENCE F33_392_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_392(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,393)
static EIF_REFERENCE F33_393_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_393(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,394)
static EIF_REFERENCE F33_394_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_394(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,395)
static EIF_REFERENCE F33_395_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_395(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,396)
static EIF_REFERENCE F33_396_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_396(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,397)
static EIF_REFERENCE F33_397_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_397(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,398)
static EIF_REFERENCE F33_398_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_398(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,399)
static EIF_REFERENCE F33_399_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_399(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,400)
static EIF_REFERENCE F33_400_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_400(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,401)
static EIF_REFERENCE F33_401_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_401(EIF_REFERENCE);
extern void EIF_Minit29(void);
extern EIF_REFERENCE F860_7467(EIF_REFERENCE);
extern EIF_REFERENCE F861_7467(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C1/ch29.h <==

#ifndef _C1_ch29_
#define _C1_ch29_

#ifdef __cplusplus
extern "C" {
#endif

extern void F33_363(EIF_REFERENCE);
extern EIF_CHARACTER_32 F33_376(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,388)
static EIF_REFERENCE F33_388_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_388(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,389)
static EIF_REFERENCE F33_389_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_389(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,390)
static EIF_REFERENCE F33_390_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_390(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,391)
static EIF_REFERENCE F33_391_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_391(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,392)
static EIF_REFERENCE F33_392_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_392(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,393)
static EIF_REFERENCE F33_393_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_393(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,394)
static EIF_REFERENCE F33_394_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_394(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,395)
static EIF_REFERENCE F33_395_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_395(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,396)
static EIF_REFERENCE F33_396_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_396(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,397)
static EIF_REFERENCE F33_397_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_397(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,398)
static EIF_REFERENCE F33_398_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_398(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,399)
static EIF_REFERENCE F33_399_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_399(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,400)
static EIF_REFERENCE F33_400_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_400(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,401)
static EIF_REFERENCE F33_401_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_401(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,402)
static EIF_REFERENCE F33_402_body(EIF_REFERENCE);
extern EIF_REFERENCE F33_402(EIF_REFERENCE);
extern void EIF_Minit29(void);
extern EIF_REFERENCE F861_7503(EIF_REFERENCE);
extern EIF_REFERENCE F862_7503(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
